@@ -93,7 +93,7 @@ def main():
     app.config['GOURD_SERVER_HOST'] = args.ghost
     app.config['GOURD_SERVER_PORT'] = args.gport
 
-    print "* Running gserver on http://%s:%s" % (args.host, args.port)
+    print "* Running gourd_http on http://%s:%s" % (args.host, args.port)
     wsgi.WSGIServer((args.host, int(args.port)), app).serve_forever()
 
 
